FAN-C command line plotting — FAN-C 0.9.1-beta documentation

# FAN-C command line plotting

The `fancplot` tool should be accessible from the command line after you installed FAN-C (see Installation). It provides basic commands for plotting Hi-C data and other genomic tracks.

- Overview and basic usage
  - Overview
  - Setting up the figure and plotting regions
  - Adding panels
  - Common parameters
- Working with Cooler, Juicer, and text files
  - Cooler `.cool` and `.mcool`
  - Juicer `.hic` files
  - Text files
- Panel types
  - Matrix panels
  - Region and score panels